@@ -38,6 +38,22 @@ class CfnConnectionAlias(
 
     :cloudformationResource: AWS::WorkSpaces::ConnectionAlias
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-connectionalias.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_workspaces as workspaces
+        
+        cfn_connection_alias = workspaces.CfnConnectionAlias(self, "MyCfnConnectionAlias",
+            connection_string="connectionString",
+        
+            # the properties below are optional
+            tags=[CfnTag(
+                key="key",
+                value="value"
+            )]
+        )
     '''
 
     def __init__(
@@ -77,12 +93,6 @@ class CfnConnectionAlias(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrAliasId")
     def attr_alias_id(self) -> builtins.str:
@@ -107,20 +117,17 @@ class CfnConnectionAlias(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrConnectionAliasState"))
 
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
-        '''``AWS::WorkSpaces::ConnectionAlias.Tags``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-connectionalias.html#cfn-workspaces-connectionalias-tags
-        '''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="connectionString")
     def connection_string(self) -> builtins.str:
@@ -134,6 +141,15 @@ class CfnConnectionAlias(
     def connection_string(self, value: builtins.str) -> None:
         jsii.set(self, "connectionString", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> aws_cdk.core.TagManager:
+        '''``AWS::WorkSpaces::ConnectionAlias.Tags``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-connectionalias.html#cfn-workspaces-connectionalias-tags
+        '''
+        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-workspaces.CfnConnectionAlias.ConnectionAliasAssociationProperty",
         jsii_struct_bases=[],
@@ -160,6 +176,19 @@ class CfnConnectionAlias(
             :param resource_id: ``CfnConnectionAlias.ConnectionAliasAssociationProperty.ResourceId``.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-connectionalias-connectionaliasassociation.html
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_workspaces as workspaces
+                
+                connection_alias_association_property = workspaces.CfnConnectionAlias.ConnectionAliasAssociationProperty(
+                    associated_account_id="associatedAccountId",
+                    association_status="associationStatus",
+                    connection_identifier="connectionIdentifier",
+                    resource_id="resourceId"
+                )
             '''
             self._values: typing.Dict[str, typing.Any] = {}
             if associated_account_id is not None:
@@ -237,6 +266,22 @@ class CfnConnectionAliasProps:
         :param tags: ``AWS::WorkSpaces::ConnectionAlias.Tags``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-connectionalias.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_workspaces as workspaces
+            
+            cfn_connection_alias_props = workspaces.CfnConnectionAliasProps(
+                connection_string="connectionString",
+            
+                # the properties below are optional
+                tags=[CfnTag(
+                    key="key",
+                    value="value"
+                )]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "connection_string": connection_string,
@@ -285,6 +330,34 @@ class CfnWorkspace(
 
     :cloudformationResource: AWS::WorkSpaces::Workspace
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_workspaces as workspaces
+        
+        cfn_workspace = workspaces.CfnWorkspace(self, "MyCfnWorkspace",
+            bundle_id="bundleId",
+            directory_id="directoryId",
+            user_name="userName",
+        
+            # the properties below are optional
+            root_volume_encryption_enabled=False,
+            tags=[CfnTag(
+                key="key",
+                value="value"
+            )],
+            user_volume_encryption_enabled=False,
+            volume_encryption_key="volumeEncryptionKey",
+            workspace_properties=workspaces.CfnWorkspace.WorkspacePropertiesProperty(
+                compute_type_name="computeTypeName",
+                root_volume_size_gib=123,
+                running_mode="runningMode",
+                running_mode_auto_stop_timeout_in_minutes=123,
+                user_volume_size_gib=123
+            )
+        )
     '''
 
     def __init__(
@@ -294,9 +367,9 @@ class CfnWorkspace(
         *,
         bundle_id: builtins.str,
         directory_id: builtins.str,
-        user_name: builtins.str,
         root_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        user_name: builtins.str,
         user_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         volume_encryption_key: typing.Optional[builtins.str] = None,
         workspace_properties: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkspace.WorkspacePropertiesProperty"]] = None,
@@ -307,9 +380,9 @@ class CfnWorkspace(
         :param id: - scoped id of the resource.
         :param bundle_id: ``AWS::WorkSpaces::Workspace.BundleId``.
         :param directory_id: ``AWS::WorkSpaces::Workspace.DirectoryId``.
-        :param user_name: ``AWS::WorkSpaces::Workspace.UserName``.
         :param root_volume_encryption_enabled: ``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
         :param tags: ``AWS::WorkSpaces::Workspace.Tags``.
+        :param user_name: ``AWS::WorkSpaces::Workspace.UserName``.
         :param user_volume_encryption_enabled: ``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
         :param volume_encryption_key: ``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
         :param workspace_properties: ``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
@@ -317,9 +390,9 @@ class CfnWorkspace(
         props = CfnWorkspaceProps(
             bundle_id=bundle_id,
             directory_id=directory_id,
-            user_name=user_name,
             root_volume_encryption_enabled=root_volume_encryption_enabled,
             tags=tags,
+            user_name=user_name,
             user_volume_encryption_enabled=user_volume_encryption_enabled,
             volume_encryption_key=volume_encryption_key,
             workspace_properties=workspace_properties,
@@ -345,26 +418,6 @@ class CfnWorkspace(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
-        '''``AWS::WorkSpaces::Workspace.Tags``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-tags
-        '''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="bundleId")
     def bundle_id(self) -> builtins.str:
@@ -378,6 +431,17 @@ class CfnWorkspace(
     def bundle_id(self, value: builtins.str) -> None:
         jsii.set(self, "bundleId", value)
 
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="directoryId")
     def directory_id(self) -> builtins.str:
@@ -391,19 +455,6 @@ class CfnWorkspace(
     def directory_id(self, value: builtins.str) -> None:
         jsii.set(self, "directoryId", value)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="userName")
-    def user_name(self) -> builtins.str:
-        '''``AWS::WorkSpaces::Workspace.UserName``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "userName"))
-
-    @user_name.setter
-    def user_name(self, value: builtins.str) -> None:
-        jsii.set(self, "userName", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rootVolumeEncryptionEnabled")
     def root_volume_encryption_enabled(
@@ -422,6 +473,28 @@ class CfnWorkspace(
     ) -> None:
         jsii.set(self, "rootVolumeEncryptionEnabled", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> aws_cdk.core.TagManager:
+        '''``AWS::WorkSpaces::Workspace.Tags``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-tags
+        '''
+        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="userName")
+    def user_name(self) -> builtins.str:
+        '''``AWS::WorkSpaces::Workspace.UserName``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "userName"))
+
+    @user_name.setter
+    def user_name(self, value: builtins.str) -> None:
+        jsii.set(self, "userName", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="userVolumeEncryptionEnabled")
     def user_volume_encryption_enabled(
@@ -500,6 +573,20 @@ class CfnWorkspace(
             :param user_volume_size_gib: ``CfnWorkspace.WorkspacePropertiesProperty.UserVolumeSizeGib``.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_workspaces as workspaces
+                
+                workspace_properties_property = workspaces.CfnWorkspace.WorkspacePropertiesProperty(
+                    compute_type_name="computeTypeName",
+                    root_volume_size_gib=123,
+                    running_mode="runningMode",
+                    running_mode_auto_stop_timeout_in_minutes=123,
+                    user_volume_size_gib=123
+                )
             '''
             self._values: typing.Dict[str, typing.Any] = {}
             if compute_type_name is not None:
@@ -578,9 +665,9 @@ class CfnWorkspace(
     name_mapping={
         "bundle_id": "bundleId",
         "directory_id": "directoryId",
-        "user_name": "userName",
         "root_volume_encryption_enabled": "rootVolumeEncryptionEnabled",
         "tags": "tags",
+        "user_name": "userName",
         "user_volume_encryption_enabled": "userVolumeEncryptionEnabled",
         "volume_encryption_key": "volumeEncryptionKey",
         "workspace_properties": "workspaceProperties",
@@ -592,9 +679,9 @@ class CfnWorkspaceProps:
         *,
         bundle_id: builtins.str,
         directory_id: builtins.str,
-        user_name: builtins.str,
         root_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        user_name: builtins.str,
         user_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         volume_encryption_key: typing.Optional[builtins.str] = None,
         workspace_properties: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkspace.WorkspacePropertiesProperty]] = None,
@@ -603,14 +690,42 @@ class CfnWorkspaceProps:
 
         :param bundle_id: ``AWS::WorkSpaces::Workspace.BundleId``.
         :param directory_id: ``AWS::WorkSpaces::Workspace.DirectoryId``.
-        :param user_name: ``AWS::WorkSpaces::Workspace.UserName``.
         :param root_volume_encryption_enabled: ``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
         :param tags: ``AWS::WorkSpaces::Workspace.Tags``.
+        :param user_name: ``AWS::WorkSpaces::Workspace.UserName``.
         :param user_volume_encryption_enabled: ``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
         :param volume_encryption_key: ``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
         :param workspace_properties: ``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_workspaces as workspaces
+            
+            cfn_workspace_props = workspaces.CfnWorkspaceProps(
+                bundle_id="bundleId",
+                directory_id="directoryId",
+                user_name="userName",
+            
+                # the properties below are optional
+                root_volume_encryption_enabled=False,
+                tags=[CfnTag(
+                    key="key",
+                    value="value"
+                )],
+                user_volume_encryption_enabled=False,
+                volume_encryption_key="volumeEncryptionKey",
+                workspace_properties=workspaces.CfnWorkspace.WorkspacePropertiesProperty(
+                    compute_type_name="computeTypeName",
+                    root_volume_size_gib=123,
+                    running_mode="runningMode",
+                    running_mode_auto_stop_timeout_in_minutes=123,
+                    user_volume_size_gib=123
+                )
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "bundle_id": bundle_id,
@@ -648,16 +763,6 @@ class CfnWorkspaceProps:
         assert result is not None, "Required property 'directory_id' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def user_name(self) -> builtins.str:
-        '''``AWS::WorkSpaces::Workspace.UserName``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
-        '''
-        result = self._values.get("user_name")
-        assert result is not None, "Required property 'user_name' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def root_volume_encryption_enabled(
         self,
@@ -678,6 +783,16 @@ class CfnWorkspaceProps:
         result = self._values.get("tags")
         return typing.cast(typing.Optional[typing.List[aws_cdk.core.CfnTag]], result)
 
+    @builtins.property
+    def user_name(self) -> builtins.str:
+        '''``AWS::WorkSpaces::Workspace.UserName``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
+        '''
+        result = self._values.get("user_name")
+        assert result is not None, "Required property 'user_name' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def user_volume_encryption_enabled(
         self,
